{% load i18n wagtailadmin_tags %}
<li class="icon icon-cog">
    <a href="{% url 'uwsgi_index' %}">
    {% blocktrans count counter=workers with workers|intcomma as total %}
        <span>{{ total }}</span> uWSGI Worker
    {% plural %}
        <span>{{ total }}</span> uWSGI Workers
    {% endblocktrans %}
    </a>
</li>
